/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ratis.protocol;

import java.io.IOException;

/** For server administration. */
public interface AdminProtocol {
  GroupListReply getGroupList(GroupListRequest request) throws IOException;

  GroupInfoReply getGroupInfo(GroupInfoRequest request) throws IOException;

  RaftClientReply groupManagement(GroupManagementRequest request) throws IOException;

  RaftClientReply snapshotManagement(SnapshotManagementRequest request) throws IOException;

  RaftClientReply leaderElectionManagement(LeaderElectionManagementRequest request) throws IOException;

  RaftClientReply setConfiguration(SetConfigurationRequest request) throws IOException;

  RaftClientReply transferLeadership(TransferLeadershipRequest request) throws IOException;
}